/*****************************************************************************************************************************************************************
*	Function name:  main.c
*	Description	:	This function calls differnet intialisation functions including	ADSP-CM40x System intialisation, CGU intialisation, Character display initialisation, 
*					SPI Memory mapped mode initialisation and more importantly ADCC initialisation including it's interrupt and trigger input initialisation.
*					After all initialisation code waits for required number of ADC samples to be received. This wait is implemented by checking ADCC TImer frame completion
*					counters which are modified in Interrupt ISR. 
*					Once the required number of ADCC frames are completed, that means, when required number of ADC samples are received in ADC_Data buffer, the "calculate_ADC_Performance" 
*					function is called. This functions calculates the some of the key ADC performance parameters such as SNR, SNDR, ENOB and THD by processing the received ADC samples.
*					Once the ADC performance parameters are calculated, those are displayed on 20 x 2 character display. optionally they can be printed on Terminal IO of IAR workbench.
*					Once this process is completed, an status LED on the EZ-KIT is toggled for indication.
*					This process continues in a while(1) loop by enabling the trigger inputs again to collect new sets of ADC samples, process them and then display the processed data. 
*	Arguments	:	None. 
*   Return value:   None.
* 	Note		:	The ADC channel to be selected for sampling is used by using ADC_SEL and CHNL_ID macros defined in main.h
*				:	The internal reference or external reference is also selected unsig EXT_REF macro defined in same file.
******************************************************************************************************************************************************************/

#include "main.h"

unsigned int delay;
int main()
{
	SystemInit();
	Init_CGU(30, 0, 4, 9); 	//	200/100 : (20, 0, 3, 6)		225/100	: (30, 0, 4, 9);		240/96  : (32, 1, 2, 5)
	SetupSPI_MMode();
    Init_Disaply();
    Init_LEDs();
	Init_Interrupts();
	Init_AFE();
	Init_ADCC_Regs();
	Init_ADCC_Timer_trigger();
	Enable_ADCC();
	
	*pREG_TIMER0_RUN_SET    =  (BITM_TIMER_RUN_SET_TMR04   | BITM_TIMER_RUN_SET_TMR05) ;
	*pREG_TIMER0_TMR4_DLY -= 20;
		
    while(1)
    {
		while(!(ADCC_TMR0_DONE && ADCC_TMR1_DONE));

        calculate_ADC_Performance();
		Display_ADC_para();
        *pREG_PORTE_DATA_TGL = BITM_PORT_DATA_TGL_PX9 ;
		clear_interrupt_state();
		*pREG_TIMER0_RUN_SET = (BITM_TIMER_RUN_SET_TMR04 | BITM_TIMER_RUN_SET_TMR05);
	} 
}


/****************************************************************************************************************************************
*	Function name:  Init_LEDs
*	Description	:	This function initialises status LED, which is toggled after completion of every cycle of ADC sample receiving and processing 
*	Arguments	:	None. 
*   Return value:   None.
*   Note		: 	This function is called at the start only by Init_Display function.
****************************************************************************************************************************************/

void Init_LEDs(void)
{
	//	Configure thse pins in GP mode by Clearing corresponding FER bits
	*pREG_PORTE_FER_CLR  = BITM_PORT_FER_CLR_PX9 ;
	*pREG_PORTE_DATA_CLR = BITM_PORT_DATA_SET_PX9 ;
	*pREG_PORTE_DIR_SET  = BITM_PORT_DIR_SET_PX9 ;
}
